Credentials class

Constructors

Credentials({required String apiKey, required String uid, required String email})
const
Credentials.fromJson(Map<String, dynamic> json)
factory

Properties

apiKey String
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → void
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

delete() → void
fromEnv() String?
load() Credentials?