BuildResolver class

Constructors

BuildResolver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseVersion(String rawVersion, String? buildNumberOverride) String
Parse version from pubspec.yaml version string (strips +buildNumber).
resolveApk(String projectRoot, String configApkPath, String? fileArg) File
Resolve the APK file to upload. Priority: --file arg > config apkPath.