GradleProjectInfo class

Project name/version resolved from an app-level Gradle file, for project types that aren't detected via pubspec.yaml (react-native, kotlin).

Constructors

GradleProjectInfo({required String projectName, required String versionName, required String versionCode, required String gradleFileLabel})
const

Properties

gradleFileLabel String
Display path of the resolved Gradle file, relative to the project root (e.g. android/app/build.gradle.kts or app/build.gradle).
final
hashCode int
The hash code for this object.
no setterinherited
projectName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionCode String
final
versionName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited