gradleFileLabel property
Display path of the resolved Gradle file, relative to the project
root (e.g. android/app/build.gradle.kts or app/build.gradle).
Implementation
final String gradleFileLabel;
Display path of the resolved Gradle file, relative to the project
root (e.g. android/app/build.gradle.kts or app/build.gradle).
final String gradleFileLabel;