RegisterResult class
Metadata-registration response — download URL + any rolled-over builds.
Constructors
-
RegisterResult({required String downloadUrl, required List<
Map< rolledOver})String, dynamic> > -
const
Properties
- downloadUrl → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rolledOver
→ List<
Map< String, dynamic> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited