ExitCodes class abstract

Constructors

ExitCodes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

apkNotFound → const int
authRejected → const int
duplicateVersion → const int
noCredentials → const int
noProjectConfig → const int
planLimit → const int
storageFailed → const int
success → const int
usage → const int