GradleProjectDetector class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolve(
String projectType, String cwd) → (GradleProjectInfo?, String?) -
Resolves GradleProjectInfo for
projectType('react-native' or 'kotlin') undercwd. Returns(null, error)with a user-facing message when the project doesn't match the expected layout.